#include <iostream>
#include <queue>
#include <climits>

struct edge {
	int v, w;
	edge(int v, int w) : v(v), w(w) {}
	friend bool operator<(const edge &l, const edge &r){
		return l.w > r.w;
	}
};
std::vector<std::vector<edge> > G;
std::vector<bool> V;
std::vector<int> D;
int N, M, S, T, L, a, b, l;

//Just standard dijkstra for the tentboys
int tents(){
	V.assign(N, false);
	D.assign(N, INT_MAX);
	D[S] = 0; D[S] = true;
	std::priority_queue<edge> pq;
	for(edge &e : G[S]){
		D[e.v] = e.w;
		pq.push(e);
	}
	
	while(!pq.empty()){
		int u = pq.top().v; pq.pop();
		if(u == T)
			break;
		if(V[u]) 
			continue;
		V[u] = true;
		
		for(const edge &e : G[u]){
			int v = e.v;
			int alt = D[u] + e.w;
			if(alt < D[v]){
				D[v] = alt;
				pq.push(e);
			}
		}
	}
	
	return D[T];
}

// Disable edges longer than L and have the group rest at cabins (handled by nextincr)
// Not yet handled: the case where it is impossible to reach the target node, 
// case not mentioned in problem statement
int cabins(){
	V.assign(N, false);
	D.assign(N, INT_MAX);
	D[S] = 0; D[S] = true;
	std::priority_queue<edge> pq;
	for(edge &e : G[S])
		if(e.w <= L){
			D[e.v] = e.w;
			pq.push(e);
		}
	
	while(!pq.empty()){
		int u = pq.top().v; pq.pop();
		if(u == T)
			break;
		if(V[u]) 
			continue;
		V[u] = true;
		

		int nextincr = D[u] + 1;
		for(int i = 0; i < L; i++)
			if(nextincr % L == 0)
				break;
			else
				nextincr++;
		// not 100% sure so throw RTE if not valid	
		if(nextincr % L != 0){
			printf("ERROR: nextincr wrong\n");
			exit(1);
		}
		
		for(const edge &e : G[u]){
			int v = e.v;
			int alt = D[u] + e.w;
			if(alt < D[v] && e.w <= L){
				D[v] = alt <= nextincr ? alt : nextincr + e.w;
				pq.push(e);
			} 
		}
	}
	
	return D[T];
}

int main(){
	scanf("%d %d %d %d %d", &N, &M, &S, &T, &L);
	G.assign(N, std::vector<edge>());
	for(int i = 0; i < M; i++){
		scanf("%d %d %d", &a, &b, &l);
		G[a].emplace_back(b,l);
		G[b].emplace_back(a,l);
	}
	printf("%d", cabins() - tents());
	return 0;
}
