import Test.QuickCheck
import Test.QuickCheck.Gen
import Test.QuickCheck.Random
import Control.Monad
import Data.List
import System.Process

takeNs :: Int -> [a] -> [[a]]
takeNs _ [] = []
takeNs n xs = take n xs : takeNs n (drop n xs)

dropNs :: Int -> [a] -> [a]
dropNs _ [] = []
dropNs n xs = take (n-1) xs ++ dropNs n (drop n xs)

caseGen :: (Int, Int, Int, Double) -> Gen String
caseGen (r, c, n, p) = do
    ladders <- (\a b -> map (\(a, b) -> [a, b]) $ zip a b) <$> shuffle [2..r*c - 1] <*> replicateM n (choose (1, r*c))
    return . unlines . map unwords $ (map show [r, c, n]):[show p]:(map (map show) ladders)

caseHardGen :: (Int, Int, Int, Double) -> Gen String
caseHardGen (r, c, n, p) = do
    ladders <- take n . (\as -> map (\a -> [a, 1]) as)
            <$> (concat <$> (shuffle $ takeNs 5 $ dropNs 6 [2..r*c - 1]))
    return . unlines . map unwords $ (map show [r, c, n]):[show p]:(map (map show) ladders)

    

cases :: [(Int, Int, Int, Double)]
--cases = [(3, 3, 1, 0.5), (3, 3, 2, 0.7), (4, 4, 3, 0.0001), (4, 4, 4, 0.9999), (5, 5, 5, 0.000001), (5, 5, 10, 0.823), (10, 10, 20, 0.9999), (10, 10, 50, 0.6), (10, 10, 50, 0.9999)]
cases = [(3, 3, 1, 0.5), (3, 3, 2, 0.7), (4, 4, 3, 0.0001), (4, 4, 4, 0.9999), (5, 5, 5, 0.000001), (5, 5, 10, 0.823), (8, 8, 20, 0.9999), (8, 8, 50, 0.6), (8, 8, 50, 0.9999)]

casesHard :: [(Int, Int, Int, Double)]
--casesHard = [(5, 5, 20, 0.5), (7, 7, 10, 0.9), (7, 7, 30, 0.7), (10, 10, 20, 0.99), (10, 10, 21, 0.997), (10, 10, 30, 0.8), (10, 10, 35, 0.9)]
casesHard = [(5, 5, 20, 0.5), (7, 7, 10, 0.9), (7, 7, 30, 0.7), (8, 8, 20, 0.99), (8, 8, 21, 0.997), (8, 8, 43, 0.9), (8, 8, 45, 0.98)]


solve :: String -> IO String
solve = readProcess "./laddergame" []

-- Standard stuff

seed :: Int
seed = 5765124

formatNum :: Int -> String
formatNum n = replicate (2 - cs) '0' ++ show n
    where
        cs = length $ show n

main :: IO ()
main = do
    callCommand "g++ -O2 -std=c++14 submissions/accepted/laddergame.cpp -o laddergame"
    putStrLn "Generating sample 0"
    let sample1 = "3 3 2\n0.4\n2 3\n4 7\n"
    writeFile ("data/sample/00.in") sample1
    sample1sol <- solve sample1
    writeFile ("data/sample/00.ans") sample1sol
    forM_ (zip [0..] cases) $ \(i, caseVars) -> do
        putStrLn $ "Generating secret " ++ show i
        let testCase = unGen (caseGen caseVars) (mkQCGen $ seed+i) (seed+i)
        writeFile ("data/secret/" ++ formatNum i ++ ".in") testCase
        solution <- solve testCase
        writeFile ("data/secret/" ++ formatNum i ++ ".ans") solution
    forM_ (zip [0..] casesHard) $ \(i, caseVars) -> do
        putStrLn $ "Generating secret hard " ++ show i
        let testCase = unGen (caseHardGen caseVars) (mkQCGen $ seed+i) (seed+i)
        writeFile ("data/secret/hard_" ++ formatNum i ++ ".in") testCase
        solution <- solve testCase
        writeFile ("data/secret/hard_" ++ formatNum i ++ ".ans") solution
    callCommand "rm laddergame"
    
    
    
