import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.*;

public class LadderGame {

    public static void main(String args[]) throws Exception {
        Input in = new Input();
        int n = in.nextInt()*in.nextInt();
        int m = in.nextInt();
        double p = in.nextDouble();

        TreeMap<Integer, Integer> ladders = new TreeMap<>();
        for (int i = 0; i < m ; i++){
            int u = in.nextInt()-1;
            int v = in.nextInt()-1;
            ladders.put(u, v);
        }

        SquareMatrix A = new SquareMatrix(n+1);

        for (int i = 0; i < n; i++){
            for (int j = 1; j <= 6; j++){
                if (i+j >= n-1) A.values[i][n-1] += 1.0 / 6.0;
                else if (ladders.containsKey(i+j)){
                    A.values[i][ladders.get(i+j)] += 1.0 / 6.0;
                }
                else A.values[i][i+j] += 1.0 / 6.0;
            }
        }
        A.values[n][n] = 1.0;

        ArrayList<SquareMatrix> powerMatrices = new ArrayList<>();
        powerMatrices.add(A);
        while (powerMatrices.get(powerMatrices.size()-1).values[0][n-1] < p){
            powerMatrices.add(powerMatrices.get(powerMatrices.size()-1).multiply(powerMatrices.get(powerMatrices.size()-1)));
        }

        SquareMatrix B = powerMatrices.get(powerMatrices.size()-2);
        int size = 1<<(powerMatrices.size()-2);
        for (int i = powerMatrices.size()-2; i >= 0; i--){
            SquareMatrix C = B.multiply(powerMatrices.get(i));
            if (C.values[0][n-1] < p){
                size += (1<<i);
                B = C;
            }
        }

        if (B.values[0][n-1] < p) size++;
        System.out.println(size);
    }

    static class SquareMatrix {
        double values[][];

        SquareMatrix(int n){
            this.values = new double[n][n];
        }

        SquareMatrix(double values[][]){
            this.values = values;
            assert (this.values.length == this.values[0].length);
        }

        SquareMatrix multiply(SquareMatrix B){
            assert (this.values.length == B.values[0].length);

            SquareMatrix C = new SquareMatrix(this.values.length);

            for (int i = 0; i < this.values.length; i++){
                for (int j = 0; j < this.values.length; j++){
                    for (int k = 0; k < this.values.length; k++){
                        C.values[i][j] += this.values[i][k]*B.values[k][j];
                    }
                }
            }

            return C;
        }

        SquareMatrix raiseToPower(int a){
            if (a == 1) return this;
            SquareMatrix B = this.raiseToPower(a / 2);
            B = B.multiply(B);
            if (a % 2 == 0) return B;
            else return this.multiply(B);
        }
    }

    static class Input{
        StringTokenizer st;
        BufferedReader br;

        Input(){
            st = new StringTokenizer("");
            br = new BufferedReader(new InputStreamReader(System.in));
        }

        int nextInt() throws Exception{
            while (!st.hasMoreTokens()) st = new StringTokenizer(br.readLine());
            return Integer.parseInt(st.nextToken());
        }

        long nextLong() throws Exception{
            while (!st.hasMoreTokens()) st = new StringTokenizer(br.readLine());
            return Long.parseLong(st.nextToken());
        }

        double nextDouble() throws Exception{
            while (!st.hasMoreTokens()) st = new StringTokenizer(br.readLine());
            return Double.parseDouble(st.nextToken());
        }

        String nextToken() throws Exception{
            while (!st.hasMoreTokens()) st = new StringTokenizer(br.readLine());
            return st.nextToken();
        }
    }
}
