#!/usr/bin/env python3
import sys, argparse, random


parser = argparse.ArgumentParser(description="Generator for landoftrees.")
parser.add_argument('-o', metavar='O', type=str, default="random",
                    help='Options for generation (random, wideclouds, shortroofs, quickclouds)')
parser.add_argument('-d', metavar='D', type=int, default=10,
                    help='distance - integer >=1 (default=10)')
parser.add_argument('-t', metavar='T', type=int, default=None,
                    help='time - integer >= d (default=2*d)')
parser.add_argument('-c', metavar='c', type=int, default=10,
                    help='number of clouds - integer >= 0 (default=10)')
parser.add_argument('-r', metavar='c', type=int, default=None,
                    help='number of roofs - integer >= 0 (default=d//4)')
parser.add_argument('-s', metavar='S', type=int, default=None,
                    help='seed for generation (optional)')
args = parser.parse_args()
random.seed(args.s)
options = args.o

d = args.d
t = args.t if args.t else 2*d
c = args.c
r = args.r if args.t else d // 4

clouds = []
roofs = []

## Generating clouds
if ("widecloud" in options):
    for i in range(c):
        s = random.randrange(1+t//100)
        e = t - random.randrange(1+t//100)
        p = random.uniform(0, 1)
        a = random.randint(0, 100)
        clouds.append("{} {} {:.6f} {}".format(s, e, round(p, 6), a))
elif ("quickclouds" in options):
    for i in range(c):
        s = random.randrange(t)
        e = s + 1
        p = random.uniform(0, 1)
        a = random.randint(0, 100)
        clouds.append("{} {} {:.6f} {}".format(s, e, round(p, 6), a))
else:
    for i in range(c):
        s, e = sorted(random.sample(range(t+1), 2))
        p = random.uniform(0, 1)
        a = random.randint(0, 100)
        clouds.append("{} {} {:.6f} {}".format(s, e, round(p, 6), a))
        

## Genrating roofs
if ("shortroofs" in options):
    places = sorted(random.sample(range(d+1), r))
    for place in places:
        roofs.append("{} {}".format(place, place+1))
else:
    places = sorted(random.sample(range(d+1), 2*r))
    for i in range(0, len(places), 2):
        roofs.append("{} {}".format(places[i], places[i+1]))


print(d, t, c, r)
print("\n".join(clouds))
print("\n".join(roofs))
