from __future__ import absolute_import, division, print_function
import sys
import os
import random
import string
import shutil
import itertools

cases = [(30, 70),
        (30, 70), 
        (30, 70), 
        (70, 140),
        (70, 140),
        (70, 140), 
        (200, 350), 
        (200, 350),
        (200, 350), 
        (700, 3000), 
        (700, 3000), 
        (700, 3000), 
        (800, 4000), 
        (800, 4000), 
        (800, 4000), 
        (1000, 5000), 
        (1000, 5000), 
        (1000, 5000),
        (1000, 10000),
        (1000, 10000),
        (1000, 10000)]


def main():
    dir_path = os.path.dirname(os.path.realpath(__file__))
    if os.getcwd() != dir_path:
        print("Not in correct directory, aborting")
        sys.exit()
    
    print("removing old secret test data")
    shutil.rmtree("data/secret", ignore_errors=True)
    os.makedirs("data/secret")

    print("generating cases...")
    for i, case in enumerate(cases):
        print("generating case %d" % (i + 1))
        case_lines = []
        d_max, t_max = case
        random.seed(i)
        d = random.randint(1, d_max)
        t = random.randint(d, t_max)
        if i % 3 == 2:
            d = d_max
            t = t_max
        r = random.randint(1, min(d // 3, 500))
        f = random.randint(1, min(t // 3, 500))
        c = random.randint(1, 200 * t)
        if i % 3 == 2:
            c = min(t * 200, 1000000)

        case_lines.append("%d %d %d %d" % (d, t, c, r))

        # generate the rain
        # how many rain intervals?
        # 100 000 is the max number, so we want max cases to have 100 000 intervals

        rain_intervals = []
        
        # add some big intervals for tle solution
        for _ in xrange(c // 2):
            rain_intervals.append((0, t))

        while len(rain_intervals) < c:
            start = random.randint(0, t - 1)
            stop = random.randint(start + 1, t)
            rain_intervals.append((start, stop))
        
        random.shuffle(rain_intervals)

        for start, stop in rain_intervals:
            prob = random.random()
            amount = random.randint(1, 100)
            case_lines.append("%d %d %.6f %d" % (start, stop, prob, amount))

        # f_starts = sorted(list(random.sample(xrange(t), f)) + [t])
        # rw = [0] * (t + 1)
        # for j in xrange(f):
        #     start = f_starts[j]
        #     stop = min(f_starts[j + 1] - 1, start + random.randint(1, d // (r * 2))) + 1
        #     prob = random.random()
        #     amount = random.randint(1, 100)
        #     for k in xrange(start, stop):
        #         rw[k] = prob * amount

        # case_lines.append(" ".join("%f" % x for x in rw))

        # generate the roofs
        r_starts = sorted(list(random.sample(xrange(1, d), r - 1)) + [0, d])
        for j in xrange(r):
            start = r_starts[j]
            stop = min(r_starts[j + 1] - 1, start + random.randint(1, d // (r * 2))) + 1
            case_lines.append("%d %d" % (start, stop))

        # case_lines.append(" ".join(0 if x else 1 for i in roofs))
        case_lines.append("")
        file_prefix = "data/secret/%02d" % (i + 1)
        with open(file_prefix + ".in", "w") as f:
            f.write("\n".join(case_lines))
        ans = solve(case_lines)
        with open(file_prefix + ".ans", "w") as f:
            f.write("\n".join(["%.6f" % ans, ""]))

def solve(lines):
    lc = 0
    d, t, c, r = (int(x) for x in lines[lc].split())
    lc += 1
    
    pre_rain = [0] * (t + 2)
    for _ in xrange(c):
        start, stop, prob, amount = lines[lc].split()
        lc += 1
        start = int(start)
        stop = int(stop)
        prob = float(prob)
        amount = int(amount)
        pre_rain[start] += prob * amount
        pre_rain[stop] -= prob * amount
    
    rain = [0] * (t + 1)
    rain[0] = pre_rain[0]
    for i in xrange(1, t + 1):
        rain[i] = rain[i - 1] + pre_rain[i]

    roofed = [False] * (d + 1)

    for _ in xrange(r):
        start, stop = (int(x) for x in lines[lc].split())
        lc += 1
        for i in xrange(start, stop):
            roofed[i] = True

    # some parts of the distance is under roofs

    dp = [[float("inf")] * (t + 1) for _ in xrange(d + 1)]
    
    roofed[0] = True

    for i in xrange(t + 1):
        dp[0][i] = 0.0

    for j in xrange(1, t + 1):
        for i in xrange(1, min(j + 1, d + 1)):
            walked = dp[i - 1][j - 1] + (rain[j - 1] if not roofed[i - 1] else 0)
            waited = dp[i][j - 1] + (rain[j - 1] if not roofed[i] else 0)
            dp[i][j] = min(walked, waited)

    return(dp[d][t])


if __name__ == '__main__':
    main()


