import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.util.*;

public class UnionOfRectangles {

    public static void main(String args[]) throws Exception {
        Input in = new Input();
        int n = in.nextInt();
        RectSide rectangles[] = new RectSide[2*n];
        TreeSet<Long> y_values = new TreeSet<>();

        y_values.add(0L);
        y_values.add((long) Integer.MAX_VALUE);

        for (int i = 0; i < n; i++){
            long x0 = in.nextInt();
            long y0 =in.nextInt();
            long x1 = in.nextInt();
            long y1 = in.nextInt();
            rectangles[2*i] = new RectSide(y0, y1, x0, true);
            rectangles[2*i+1] = new RectSide(y0, y1, x1, false);
            y_values.add(y0);
            y_values.add(y1);
        }

        //scanline
        Arrays.sort(rectangles);
        long lastX = rectangles[0].x_value;
        long area = 0;
        SegmentTree st = new SegmentTree(y_values);
        for (RectSide rect: rectangles){
            area += (rect.x_value - lastX) * st.covered();
            if (rect.leftSide) st.add(rect.low, rect.high);
            else st.remove(rect.low, rect.high);
            lastX = rect.x_value;
        }

        System.out.println(area);
    }

    static class RectSide implements Comparable<RectSide>{
        long low, high;
        long x_value;
        boolean leftSide;

        RectSide(long l, long h, long x, boolean left){
            low = l;
            high = h;
            x_value = x;
            leftSide = left;
        }

        public int compareTo(RectSide r){
            return (int) x_value - (int) r.x_value;
        }
    }

    static class SegmentTree{
        HashMap<Long, Integer> map;
        long subtree[];
        int segmentcovered[];
        long lengthofsegment[];
        int offset;

        SegmentTree(TreeSet<Long> values){
            map = new HashMap<>();
            int i = 2;
            while (i <= 2*values.size() + 10) i *= 2;
            offset = i/2 + 5;
            subtree = new long[i];
            segmentcovered = new int[i];
            lengthofsegment = new long[i];

            ArrayList<Long> vals = new ArrayList<>(); vals.addAll(values);
            for (int j = 0; j < vals.size(); j++) {
                map.put(vals.get(j), j+offset);
                if (j+1 < vals.size()) lengthofsegment[j+offset] = vals.get(j+1) - vals.get(j);
            }
            for (int j = i / 2-1; j > 0; j--){
                lengthofsegment[j] = lengthofsegment[2*j]+lengthofsegment[2*j+1];
            }
        }

        long covered(){
            if (segmentcovered[1] > 0) return lengthofsegment[1];
            return subtree[1];
        }

        void add(long low, long high){
            int l = map.get(low)-1;
            int r = map.get(high);
            int dl = 0;
            int dr = 0;

            while (true){
                int nl = l / 2;
                int nr = r / 2;
                if (nl == nr) break;

                if (2*nl == l){
                    segmentcovered[2*nl+1] += 1;
                    if (segmentcovered[2*nl+1] == 1){
                        dl += lengthofsegment[2*nl+1] - subtree[2*nl+1];
                    }
                }
                if (2*nr+1 == r){
                    segmentcovered[2*nr] += 1;
                    if (segmentcovered[2*nr] == 1){
                        dr += lengthofsegment[2*nr] - subtree[2*nr];
                    }
                }

                subtree[nl] += dl;
                subtree[nr] += dr;
                if (segmentcovered[nl] > 0) dl = 0;
                if (segmentcovered[nr] > 0) dr = 0;
                l = nl;
                r = nr;
            }
            l = l / 2;
            int d = dl + dr;
            while (l > 0){
                subtree[l] += d;
                if (segmentcovered[l] > 0) d = 0;
                l = l / 2;
            }
        }

        void remove(long low, long high){
            int l = map.get(low)-1;
            int r = map.get(high);
            int dl = 0;
            int dr = 0;

            while (true){
                int nl = l / 2;
                int nr = r / 2;
                if (nl == nr) break;

                if (2*nl == l){
                    segmentcovered[2*nl+1] -= 1;
                    if (segmentcovered[2*nl+1] == 0){
                        dl -= lengthofsegment[2*nl+1] - subtree[2*nl+1];
                    }
                }
                if (2*nr+1 == r){
                    segmentcovered[2*nr] -= 1;
                    if (segmentcovered[2*nr] == 0){
                        dr -= lengthofsegment[2*nr] - subtree[2*nr];
                    }
                }

                subtree[nl] += dl;
                subtree[nr] += dr;
                if (segmentcovered[nl] > 0) dl = 0;
                if (segmentcovered[nr] > 0) dr = 0;
                l = nl;
                r = nr;
            }
            l = l / 2;
            int d = dl + dr;
            while (l > 0){
                subtree[l] += d;
                if (segmentcovered[l] > 0) d = 0;
                l = l / 2;
            }
        }
    }

    static class Input{
        StringTokenizer st;
        BufferedReader br;

        Input(){
            st = new StringTokenizer("");
            br = new BufferedReader(new InputStreamReader(System.in));
        }

        int nextInt() throws Exception{
            while (!st.hasMoreTokens()) st = new StringTokenizer(br.readLine());
            return Integer.parseInt(st.nextToken());
        }

        long nextLong() throws Exception{
            while (!st.hasMoreTokens()) st = new StringTokenizer(br.readLine());
            return Long.parseLong(st.nextToken());
        }

        double nextDouble() throws Exception{
            while (!st.hasMoreTokens()) st = new StringTokenizer(br.readLine());
            return Double.parseDouble(st.nextToken());
        }

        String nextToken() throws Exception{
            while (!st.hasMoreTokens()) st = new StringTokenizer(br.readLine());
            return st.nextToken();
        }
    }
}
