#include <iostream>
#include <vector>
#include <algorithm>
#include <memory>

using namespace std;

using ll = long long;

struct SegmentTree {
    int li;
    int ri;
    unique_ptr<SegmentTree> l;
    unique_ptr<SegmentTree> r;

    ll value = 0;
    ll score = 0;

    SegmentTree(int l, int r) : li(l), ri(r) {}

    void update(int f, int t, ll x)  {
        if (li > t || ri < f) return;

        if (f <= li && t >= ri) {
            value += x;
        }
        else {
            if (!l) l = make_unique<SegmentTree>(li, (li+ri)/2);
            if (!r) r = make_unique<SegmentTree>((li+ri)/2+1, ri);
            l->update(f, t, x);
            r->update(f, t, x);
        }
        if (l && r) score = l->score + r->score;
        else score = 0;

        if (value > 0) score = ri - li + 1;
    }
};

struct event {
    int x;
    int y1;
    int y2;
    int d;

    bool operator< (const event &other) const {
        return x < other.x;
    }
};

constexpr int MAXN = 100000;
constexpr int MAXC = 1000000000;

int n;
event E[MAXN*2];

int main() {
    cin >> n;
    SegmentTree tree(0, MAXC);

    for (int i = 0; i < n; i++) {
        int x1, x2, y1, y2;
        cin >> x1 >> y1 >> x2 >> y2;
        y2--;
        E[i*2] = {x1, y1, y2, 1};
        E[i*2+1] = {x2, y1, y2, -1};
    }

    sort(E, E+n*2);

    ll area = 0;
    int last_x = 0;
    for (int i = 0; i < n*2; i++) {
        area += tree.score * (E[i].x - last_x);
        tree.update(E[i].y1, E[i].y2, {E[i].d});
        last_x = E[i].x;
    }

    cout << area << endl;
}
