#include <iostream>
#include <vector>
#include <algorithm>
#include <memory>

using namespace std;

using ll = long long;

template<class E, class L, class O>
class SegmentTree {
    int li;
    int ri;
    unique_ptr<SegmentTree> l;
    unique_ptr<SegmentTree> r;

    E val;
    L lazy;

    void propognate_lazy() {
        val = O::add_lazy(val, lazy);
        lazy = O::le;
    }

    E getVal() {
        propognate_lazy();
        return val;
    }


public: 
    SegmentTree(int l, int r) : li(l), ri(r), val(O::e(l, r)), lazy(O::le) {}

    E get(int f, int t) {
        propognate_lazy();
        if (f <= li && t >= ri) return val;
        if (li > t || ri < f) return O::e(li, ri);

        return O::combine(val, l->get(f, t), r->get(f, t));
    }

    void update(int f, int t, L x)  {
        propognate_lazy();
        if (li > t || ri < f) return;

        if (f <= li && t >= ri) {
            lazy.append(x);
            propognate_lazy();
        }
        else {
            if (!l) l = make_unique<SegmentTree<E, L, O>>(li, (li+ri)/2);
            if (!r) r = make_unique<SegmentTree<E, L, O>>((li+ri)/2+1, ri);
            l->update(f, t, x);
            r->update(f, t, x);
        }
        if (l && r) val = O::combine(val, l->getVal(), r->getVal());
        else val = O::combine(val, O::e(li, li), O::e(ri, ri));
    }
};

struct segment {
    ll value;
    ll score;
    ll size;
};

struct lazy {
    int add;

    void append(const lazy &other) {
        add += other.add;
    }
};

struct op {
    static constexpr lazy le = {0};

    static segment e(int l, int r) {
        segment res = {0, 0, 0};
        res.size = r - l + 1;
        return res;
    }

    static segment combine(segment res, segment a, segment b) {
        if (res.value > 0)
            res.score = res.size;
        else if (res.value == 0) 
            res.score = a.score + b.score;

        return res;
    }

    static segment add_lazy(segment val, lazy l) {
        val.value += l.add;

        return val;
    }
};

struct event {
    int x;
    int y1;
    int y2;
    int d;

    bool operator< (const event &other) const {
        return x < other.x;
    }
};

constexpr int MAXN = 100000;
constexpr int MAXC = 1000000000;

int n;
event E[MAXN*2];

int main() {
    cin >> n;
    SegmentTree<segment, lazy, op> tree(0, MAXC);

    for (int i = 0; i < n; i++) {
        int x1, x2, y1, y2;
        cin >> x1 >> y1 >> x2 >> y2;
        y2--;
        E[i*2] = {x1, y1, y2, 1};
        E[i*2+1] = {x2, y1, y2, -1};
    }

    sort(E, E+n*2);

    ll area = 0;
    int last_x = 0;
    for (int i = 0; i < n*2; i++) {
        area += tree.get(0, MAXC).score * (E[i].x - last_x);
        tree.update(E[i].y1, E[i].y2, {E[i].d});
        last_x = E[i].x;
    }

    cout << area << endl;
}
